@@ -4,7 +4,7 @@ from ...Internal.CommandsGroup import CommandsGroup
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
 class Action:
-	"""Action commands group definition. 5 total commands, 4 Sub-groups, 0 group commands"""
+	"""Action commands group definition. 4 total commands, 3 Sub-groups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
 		self._core = core
@@ -34,14 +34,6 @@ class Action:
 			self._station = Station(self._core, self._base)
 		return self._station
 
-	@property
-	def disconnect(self):
-		"""disconnect commands group. 0 Sub-classes, 1 commands."""
-		if not hasattr(self, '_disconnect'):
-			from .Action_.Disconnect import Disconnect
-			self._disconnect = Disconnect(self._core, self._base)
-		return self._disconnect
-
 	def clone(self) -> 'Action':
 		"""Clones the group by creating new object from it and its whole existing sub-groups
 		Also copies all the existing default Repeated Capabilities setting,
