@@ -9,12 +9,20 @@ from ... import enums
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
 class Connection:
-	"""Connection commands group definition. 104 total commands, 15 Sub-groups, 17 group commands"""
+	"""Connection commands group definition. 100 total commands, 16 Sub-groups, 16 group commands"""
 
 	def __init__(self, core: Core, parent):
 		self._core = core
 		self._base = CommandsGroup("connection", core, parent)
 
+	@property
+	def association(self):
+		"""association commands group. 1 Sub-classes, 3 commands."""
+		if not hasattr(self, '_association'):
+			from .Connection_.Association import Association
+			self._association = Association(self._core, self._base)
+		return self._association
+
 	@property
 	def hotspot(self):
 		"""hotspot commands group. 3 Sub-classes, 4 commands."""
@@ -49,7 +57,7 @@ class Connection:
 
 	@property
 	def qos(self):
-		"""qos commands group. 0 Sub-classes, 4 commands."""
+		"""qos commands group. 0 Sub-classes, 2 commands."""
 		if not hasattr(self, '_qos'):
 			from .Connection_.Qos import Qos
 			self._qos = Qos(self._core, self._base)
@@ -64,16 +72,16 @@ class Connection:
 		return self._srates
 
 	@property
-	def dframe(self):
-		"""dframe commands group. 1 Sub-classes, 0 commands."""
-		if not hasattr(self, '_dframe'):
-			from .Connection_.Dframe import Dframe
-			self._dframe = Dframe(self._core, self._base)
-		return self._dframe
+	def sta(self):
+		"""sta commands group. 1 Sub-classes, 0 commands."""
+		if not hasattr(self, '_sta'):
+			from .Connection_.Sta import Sta
+			self._sta = Sta(self._core, self._base)
+		return self._sta
 
 	@property
 	def hetf(self):
-		"""hetf commands group. 1 Sub-classes, 19 commands."""
+		"""hetf commands group. 1 Sub-classes, 10 commands."""
 		if not hasattr(self, '_hetf'):
 			from .Connection_.Hetf import Hetf
 			self._hetf = Hetf(self._core, self._base)
@@ -113,7 +121,7 @@ class Connection:
 
 	@property
 	def ndpSounding(self):
-		"""ndpSounding commands group. 1 Sub-classes, 9 commands."""
+		"""ndpSounding commands group. 1 Sub-classes, 13 commands."""
 		if not hasattr(self, '_ndpSounding'):
 			from .Connection_.NdpSounding import NdpSounding
 			self._ndpSounding = NdpSounding(self._core, self._base)
@@ -173,6 +181,24 @@ class Connection:
 		param = Conversions.enum_scalar_to_str(mode, enums.EntityOperationMode)
 		self._core.io.write(f'CONFigure:WLAN:SIGNaling<Instance>:CONNection:OMODe {param}')
 
+	def get_mstation(self) -> bool:
+		"""SCPI: CONFigure:WLAN:SIGNaling<instance>:CONNection:MSTation \n
+		Snippet: value: bool = driver.configure.connection.get_mstation() \n
+		Enables or disables the support of multi-station connection. \n
+			:return: enable: OFF | ON
+		"""
+		response = self._core.io.query_str('CONFigure:WLAN:SIGNaling<Instance>:CONNection:MSTation?')
+		return Conversions.str_to_bool(response)
+
+	def set_mstation(self, enable: bool) -> None:
+		"""SCPI: CONFigure:WLAN:SIGNaling<instance>:CONNection:MSTation \n
+		Snippet: driver.configure.connection.set_mstation(enable = False) \n
+		Enables or disables the support of multi-station connection. \n
+			:param enable: OFF | ON
+		"""
+		param = Conversions.bool_to_str(enable)
+		self._core.io.write(f'CONFigure:WLAN:SIGNaling<Instance>:CONNection:MSTation {param}')
+
 	# noinspection PyTypeChecker
 	def get_smoothing(self) -> enums.SmoothingBit:
 		"""SCPI: CONFigure:WLAN:SIGNaling<instance>:CONNection:SMOothing \n
@@ -244,61 +270,6 @@ class Connection:
 		"""
 		self._core.io.write_struct('CONFigure:WLAN:SIGNaling<Instance>:CONNection:MFDef', value)
 
-	# noinspection PyTypeChecker
-	class DfdefStruct(StructBase):
-		"""Structure for reading output parameters. Fields: \n
-			- State: enums.EnableState: DISable | ENABle Disables/enables the user-defined frame rate control
-			- Format_Py: enums.DataFormatExt: NHT | HTM | VHT | HES | HEM Selects the frame format NHT: non-high throughput format (non-HT) HTM: HT mixed format (HT MF) VHT: very high throughput format HES: high efficiency single-user format (HE SU) HEM: high efficiency multi-user format (HE MU)
-			- Chan_Bw: enums.ChannelBandwidthDut: BW20 | BW40 | BW80 | BW160 Channel bandwidth The value must not exceed the operating channel bandwidth, see [CMDLINK: CONFigure:WLAN:SIGNi:RFSettings:OCWidth CMDLINK].
-			- Rate: enums.CodeRate: D1MBit | D2MBits | C55Mbits | C11Mbits | BR12 | BR34 | QR12 | QR34 | Q1M12 | Q1M34 | Q6M23 | Q6M34 | MCS | MCS1 | MCS2 | MCS3 | MCS4 | MCS5 | MCS6 | MCS7 | MCS8 | MCS9 | MCS10 | MCS11 | MCS12 | MCS13 | MCS14 | MCS15 See rate list in [CMDLINK: CONFigure:WLAN:SIGNi:CONNection:MFDef CMDLINK]
-			- Guard_Interval: enums.GuardInterval: LONG | SHORt | GI08 | GI16 | GI32 SHORt, LONG: short or long guard interval (up to IEEE 802.11ac) GI08, GI16, GI32: 0.8 μs, 1.6 μs, and 3.2 μs guard interval durations (for IEEE 802.11ax)
-			- Lt_Ftype: enums.LtfType: X1 | X2 | X4 1x LTF, 2x LTF, 4x LTF for 802.11ax
-			- Pe_Duration: enums.PeDuration: PE0 | PE4 | PE8 | PE12 | PE16 | AUTO PEx: additional receive processing time of x μs signaled in packet extension (PE) field (only for IEEE 802.11ax) AUTO: automatic setting based on the reported DUTs capabilities
-			- Ctype: enums.CodingType: LDPC | BCC Coding type (for IEEE 802.11ax - VHT, HE_SU, HE_MU frames only) : low density parity check or binary convolution code
-			- Streams: enums.Streams: STR1 | STR2 Number of streams
-			- Stbc: bool: OFF | ON Enables / disables space time block coding (STBC) . If disabled, spatial multiplexing is used."""
-		__meta_args_list = [
-			ArgStruct.scalar_enum('State', enums.EnableState),
-			ArgStruct.scalar_enum('Format_Py', enums.DataFormatExt),
-			ArgStruct.scalar_enum('Chan_Bw', enums.ChannelBandwidthDut),
-			ArgStruct.scalar_enum('Rate', enums.CodeRate),
-			ArgStruct.scalar_enum('Guard_Interval', enums.GuardInterval),
-			ArgStruct.scalar_enum('Lt_Ftype', enums.LtfType),
-			ArgStruct.scalar_enum('Pe_Duration', enums.PeDuration),
-			ArgStruct.scalar_enum('Ctype', enums.CodingType),
-			ArgStruct.scalar_enum('Streams', enums.Streams),
-			ArgStruct.scalar_bool('Stbc')]
-
-		def __init__(self):
-			StructBase.__init__(self, self)
-			self.State: enums.EnableState = None
-			self.Format_Py: enums.DataFormatExt = None
-			self.Chan_Bw: enums.ChannelBandwidthDut = None
-			self.Rate: enums.CodeRate = None
-			self.Guard_Interval: enums.GuardInterval = None
-			self.Lt_Ftype: enums.LtfType = None
-			self.Pe_Duration: enums.PeDuration = None
-			self.Ctype: enums.CodingType = None
-			self.Streams: enums.Streams = None
-			self.Stbc: bool = None
-
-	# noinspection PyTypeChecker
-	def get_dfdef(self) -> DfdefStruct:
-		"""SCPI: CONFigure:WLAN:SIGNaling<instance>:CONNection:DFDef \n
-		Snippet: value: DfdefStruct = driver.configure.connection.get_dfdef() \n
-		Enables and configures the user-defined frame rate control for data frames. \n
-			:return: structure: for return value, see the help for DfdefStruct structure arguments.
-		"""
-		return self._core.io.query_struct('CONFigure:WLAN:SIGNaling<Instance>:CONNection:DFDef?', self.__class__.DfdefStruct())
-
-	def set_dfdef(self, value: DfdefStruct) -> None:
-		"""SCPI: CONFigure:WLAN:SIGNaling<instance>:CONNection:DFDef \n
-		Snippet: driver.configure.connection.set_dfdef(value = DfdefStruct()) \n
-		Enables and configures the user-defined frame rate control for data frames. \n
-			:param value: see the help for DfdefStruct structure arguments.
-		"""
-		self._core.io.write_struct('CONFigure:WLAN:SIGNaling<Instance>:CONNection:DFDef', value)
-
 	def get_sync(self) -> bool:
 		"""SCPI: CONFigure:WLAN:SIGNaling<instance>:CONNection:SYNC \n
 		Snippet: value: bool = driver.configure.connection.get_sync() \n
@@ -458,40 +429,6 @@ class Connection:
 		param = Conversions.enum_scalar_to_str(typ, enums.StandardType)
 		self._core.io.write(f'CONFigure:WLAN:SIGNaling<Instance>:CONNection:STANdard {param}')
 
-	# noinspection PyTypeChecker
-	class AmpduStruct(StructBase):
-		"""Structure for reading output parameters. Fields: \n
-			- Enable: enums.EnableState: DISable | ENABle Enables/ disables the A-MPDUs
-			- Multi_Tid: enums.EnableState: DISable | ENABle Enables/ disables multi-TID A-MPDU
-			- Max_Length: int: integer The maximal length of entire A-MPDU Range: 50 to 131.071E+3, Unit: byte"""
-		__meta_args_list = [
-			ArgStruct.scalar_enum('Enable', enums.EnableState),
-			ArgStruct.scalar_enum('Multi_Tid', enums.EnableState),
-			ArgStruct.scalar_int('Max_Length')]
-
-		def __init__(self):
-			StructBase.__init__(self, self)
-			self.Enable: enums.EnableState = None
-			self.Multi_Tid: enums.EnableState = None
-			self.Max_Length: int = None
-
-	# noinspection PyTypeChecker
-	def get_ampdu(self) -> AmpduStruct:
-		"""SCPI: CONFigure:WLAN:SIGNaling<instance>:CONNection:AMPDu \n
-		Snippet: value: AmpduStruct = driver.configure.connection.get_ampdu() \n
-		Configures aggregate MPDUs (A-MPDU) . \n
-			:return: structure: for return value, see the help for AmpduStruct structure arguments.
-		"""
-		return self._core.io.query_struct('CONFigure:WLAN:SIGNaling<Instance>:CONNection:AMPDu?', self.__class__.AmpduStruct())
-
-	def set_ampdu(self, value: AmpduStruct) -> None:
-		"""SCPI: CONFigure:WLAN:SIGNaling<instance>:CONNection:AMPDu \n
-		Snippet: driver.configure.connection.set_ampdu(value = AmpduStruct()) \n
-		Configures aggregate MPDUs (A-MPDU) . \n
-			:param value: see the help for AmpduStruct structure arguments.
-		"""
-		self._core.io.write_struct('CONFigure:WLAN:SIGNaling<Instance>:CONNection:AMPDu', value)
-
 	# noinspection PyTypeChecker
 	class DyFragmentStruct(StructBase):
 		"""Structure for reading output parameters. Fields: \n
@@ -526,8 +463,9 @@ class Connection:
 	def get_dsss(self) -> bool:
 		"""SCPI: CONFigure:WLAN:SIGNaling<instance>:CONNection:DSSS \n
 		Snippet: value: bool = driver.configure.connection.get_dsss() \n
-		No command help available \n
-			:return: support_of_dsss: No help available
+		Enables you to associate an 802.11b device using 802.11ac or ax standard. Also, it enables you to use non-HT management
+		frames within 802.11ac and ax. \n
+			:return: support_of_dsss: OFF | ON
 		"""
 		response = self._core.io.query_str('CONFigure:WLAN:SIGNaling<Instance>:CONNection:DSSS?')
 		return Conversions.str_to_bool(response)
@@ -535,8 +473,9 @@ class Connection:
 	def set_dsss(self, support_of_dsss: bool) -> None:
 		"""SCPI: CONFigure:WLAN:SIGNaling<instance>:CONNection:DSSS \n
 		Snippet: driver.configure.connection.set_dsss(support_of_dsss = False) \n
-		No command help available \n
-			:param support_of_dsss: No help available
+		Enables you to associate an 802.11b device using 802.11ac or ax standard. Also, it enables you to use non-HT management
+		frames within 802.11ac and ax. \n
+			:param support_of_dsss: OFF | ON
 		"""
 		param = Conversions.bool_to_str(support_of_dsss)
 		self._core.io.write(f'CONFigure:WLAN:SIGNaling<Instance>:CONNection:DSSS {param}')
