@@ -16,7 +16,7 @@ class State:
 	def fetch(self) -> enums.PsState:
 		"""SCPI: FETCh:WLAN:SIGNaling<instance>:PSWitched:STATe \n
 		Snippet: value: enums.PsState = driver.pswitched.state.fetch() \n
-		Gets the connection status. \n
+		Gets the connection status, refer to 'Connection Status'. Commands for station one, two and three are available. \n
 			:return: ps_state: IDLE | PROBed | AUTHenticated | ASSociated | DEAuthenticated | DISassociated | CTIMeout"""
 		response = self._core.io.query_str(f'FETCh:WLAN:SIGNaling<Instance>:PSWitched:STATe?')
 		return Conversions.str_to_scalar_enum(response, enums.PsState)
