@@ -111,6 +111,13 @@ class Ch20Index(Enum):
 	CHA4 = 3
 
 
+# noinspection SpellCheckingInspection
+class Channel80MhZ(Enum):
+	"""2 Members, PRIMary ... SECondary"""
+	PRIMary = 0
+	SECondary = 1
+
+
 # noinspection SpellCheckingInspection
 class ChannelBandwidth(Enum):
 	"""5 Members, BW16 ... BW88"""
@@ -297,11 +304,13 @@ class FlowType(Enum):
 
 # noinspection SpellCheckingInspection
 class FrameFormat(Enum):
-	"""4 Members, HE ... VHT"""
-	HE = 0
-	HT = 1
-	NHT = 2
-	VHT = 3
+	"""6 Members, HEMU ... VHT"""
+	HEMU = 0
+	HESU = 1
+	HETB = 2
+	HT = 3
+	NHT = 4
+	VHT = 5
 
 
 # noinspection SpellCheckingInspection
@@ -487,6 +496,20 @@ class NetAuthTypeInd(Enum):
 	OESupported = 3
 
 
+# noinspection SpellCheckingInspection
+class Ngrouping(Enum):
+	"""2 Members, GRP16 ... GRP4"""
+	GRP16 = 0
+	GRP4 = 1
+
+
+# noinspection SpellCheckingInspection
+class NumColumns(Enum):
+	"""2 Members, COL1 ... COL2"""
+	COL1 = 0
+	COL2 = 1
+
+
 # noinspection SpellCheckingInspection
 class NumOfDigits(Enum):
 	"""2 Members, THDigits ... TWDigits"""
@@ -778,9 +801,17 @@ class PowerIndicator(Enum):
 
 # noinspection SpellCheckingInspection
 class PrioMode(Enum):
-	"""2 Members, ROURobin ... TIDPriority"""
-	ROURobin = 0
-	TIDPriority = 1
+	"""3 Members, AUTO ... TIDPriority"""
+	AUTO = 0
+	ROURobin = 1
+	TIDPriority = 2
+
+
+# noinspection SpellCheckingInspection
+class PrioModeB(Enum):
+	"""2 Members, AUTO ... ROURobin"""
+	AUTO = 0
+	ROURobin = 1
 
 
 # noinspection SpellCheckingInspection
@@ -838,6 +869,14 @@ class Repeat(Enum):
 	SINGleshot = 1
 
 
+# noinspection SpellCheckingInspection
+class Reservation(Enum):
+	"""3 Members, ANY ... SET"""
+	ANY = 0
+	OFF = 1
+	SET = 2
+
+
 # noinspection SpellCheckingInspection
 class ResourceState(Enum):
 	"""8 Members, ACTive ... RUN"""
@@ -871,76 +910,77 @@ class RuAlloc(Enum):
 
 # noinspection SpellCheckingInspection
 class RuAllocation(Enum):
-	"""69 Members, RU0 ... RU9"""
-	RU0 = 0
-	RU1 = 1
-	RU10 = 2
-	RU11 = 3
-	RU12 = 4
-	RU13 = 5
-	RU14 = 6
-	RU15 = 7
-	RU16 = 8
-	RU17 = 9
-	RU18 = 10
-	RU19 = 11
-	RU2 = 12
-	RU20 = 13
-	RU21 = 14
-	RU22 = 15
-	RU23 = 16
-	RU24 = 17
-	RU25 = 18
-	RU26 = 19
-	RU27 = 20
-	RU28 = 21
-	RU29 = 22
-	RU3 = 23
-	RU30 = 24
-	RU31 = 25
-	RU32 = 26
-	RU33 = 27
-	RU34 = 28
-	RU35 = 29
-	RU36 = 30
-	RU37 = 31
-	RU38 = 32
-	RU39 = 33
-	RU4 = 34
-	RU40 = 35
-	RU41 = 36
-	RU42 = 37
-	RU43 = 38
-	RU44 = 39
-	RU45 = 40
-	RU46 = 41
-	RU47 = 42
-	RU48 = 43
-	RU49 = 44
-	RU5 = 45
-	RU50 = 46
-	RU51 = 47
-	RU52 = 48
-	RU53 = 49
-	RU54 = 50
-	RU55 = 51
-	RU56 = 52
-	RU57 = 53
-	RU58 = 54
-	RU59 = 55
-	RU6 = 56
-	RU60 = 57
-	RU61 = 58
-	RU62 = 59
-	RU63 = 60
-	RU64 = 61
-	RU65 = 62
-	RU66 = 63
-	RU67 = 64
-	RU68 = 65
-	RU7 = 66
-	RU8 = 67
-	RU9 = 68
+	"""70 Members, OFF ... RU9"""
+	OFF = 0
+	RU0 = 1
+	RU1 = 2
+	RU10 = 3
+	RU11 = 4
+	RU12 = 5
+	RU13 = 6
+	RU14 = 7
+	RU15 = 8
+	RU16 = 9
+	RU17 = 10
+	RU18 = 11
+	RU19 = 12
+	RU2 = 13
+	RU20 = 14
+	RU21 = 15
+	RU22 = 16
+	RU23 = 17
+	RU24 = 18
+	RU25 = 19
+	RU26 = 20
+	RU27 = 21
+	RU28 = 22
+	RU29 = 23
+	RU3 = 24
+	RU30 = 25
+	RU31 = 26
+	RU32 = 27
+	RU33 = 28
+	RU34 = 29
+	RU35 = 30
+	RU36 = 31
+	RU37 = 32
+	RU38 = 33
+	RU39 = 34
+	RU4 = 35
+	RU40 = 36
+	RU41 = 37
+	RU42 = 38
+	RU43 = 39
+	RU44 = 40
+	RU45 = 41
+	RU46 = 42
+	RU47 = 43
+	RU48 = 44
+	RU49 = 45
+	RU5 = 46
+	RU50 = 47
+	RU51 = 48
+	RU52 = 49
+	RU53 = 50
+	RU54 = 51
+	RU55 = 52
+	RU56 = 53
+	RU57 = 54
+	RU58 = 55
+	RU59 = 56
+	RU6 = 57
+	RU60 = 58
+	RU61 = 59
+	RU62 = 60
+	RU63 = 61
+	RU64 = 62
+	RU65 = 63
+	RU66 = 64
+	RU67 = 65
+	RU68 = 66
+	RU7 = 67
+	RU8 = 68
+	RU9 = 69
 
 
 # noinspection SpellCheckingInspection
@@ -1190,6 +1230,13 @@ class SegmentNumber(Enum):
 	C = 2
 
 
+# noinspection SpellCheckingInspection
+class Size(Enum):
+	"""2 Members, SIZE0 ... SIZE1"""
+	SIZE0 = 0
+	SIZE1 = 1
+
+
 # noinspection SpellCheckingInspection
 class SmoothingBit(Enum):
 	"""2 Members, NRECommended ... RECommended"""
@@ -1242,6 +1289,14 @@ class StandardType(Enum):
 	NGFStd = 9
 
 
+# noinspection SpellCheckingInspection
+class Station(Enum):
+	"""3 Members, STA1 ... STA3"""
+	STA1 = 0
+	STA2 = 1
+	STA3 = 2
+
+
 # noinspection SpellCheckingInspection
 class Streams(Enum):
 	"""2 Members, STR1 ... STR2"""
